@@ -3,7 +3,7 @@
 #define ALLOC(a,b) S_alloc(a,b)
 
 
-#include <R_ext/Mathlib.h>
+#include "Rmath.h"
 #ifndef erf
 #define erf(x) (2*pnorm5((x)*M_SQRT2,0,1,1,0)-1)
 #endif
